# Strip field outer divs

This module allow you to strip any surrounding div around your field value.
The code is based on drupal doc : https://www.drupal.org/node/2130757.

## Install module

Use composer : `composer require drupal/field_stripouter`

Activate the module as you usually do.

## Use module in your theme

You need to add a `field.html.twig` (preferably comming from core) in your theme with following modification :

```
{% if stripouter_valueonly %}:

  {% for item in items %}
    {{ item.content }}
  {% endfor %}

{% else %}

  <!-- content from field.html.twig -->

{% endif %}
```

Resulting mytheme/templates/field.html.twig :

```
{#
/**
 * @file
 * Default theme implementation for a field.
 *
 * To override output, copy the "field.html.twig" from the templates directory
 * to your theme's directory and customize it, just like customizing other
 * Drupal templates such as page.html.twig or node.html.twig.
 *
 * Instead of overriding the theming for all fields, you can also just override
 * theming for a subset of fields using
 * @link themeable Theme hook suggestions. @endlink For example,
 * here are some theme hook suggestions that can be used for a field_foo field
 * on an article node type:
 * - field--node--field-foo--article.html.twig
 * - field--node--field-foo.html.twig
 * - field--node--article.html.twig
 * - field--field-foo.html.twig
 * - field--text-with-summary.html.twig
 * - field.html.twig
 *
 * Available variables:
 * - attributes: HTML attributes for the containing element.
 * - label_hidden: Whether to show the field label or not.
 * - title_attributes: HTML attributes for the title.
 * - label: The label for the field.
 * - multiple: TRUE if a field can contain multiple items.
 * - items: List of all the field items. Each item contains:
 *   - attributes: List of HTML attributes for each item.
 *   - content: The field item's content.
 * - entity_type: The entity type to which the field belongs.
 * - field_name: The name of the field.
 * - field_type: The type of the field.
 * - label_display: The display settings for the label.
 *
 * @see template_preprocess_field()
 *
 * @ingroup themeable
 */
#}
{%
  set title_classes = [
    label_display == 'visually_hidden' ? 'visually-hidden',
  ]
%}

{% if op_valueonly %}:

  {% for item in items %}
    {{ item.content }}
  {% endfor %}

{% else %}

  {% if label_hidden %}
    {% if multiple %}
      <div{{ attributes }}>
        {% for item in items %}
          <div{{ item.attributes }}>{{ item.content }}</div>
        {% endfor %}
      </div>
    {% else %}
      {% for item in items %}
        <div{{ attributes }}>{{ item.content }}</div>
      {% endfor %}
    {% endif %}
  {% else %}
    <div{{ attributes }}>
      <div{{ title_attributes.addClass(title_classes) }}>{{ label }}</div>
      {% if multiple %}
        <div>
      {% endif %}
      {% for item in items %}
        <div{{ item.attributes }}>{{ item.content }}</div>
      {% endfor %}
      {% if multiple %}
        </div>
      {% endif %}
    </div>
  {% endif %}

{% endif %}
```
